aboutsummaryrefslogtreecommitdiff
path: root/backends/PalmOS/Src
diff options
context:
space:
mode:
authorJoost Peters2005-02-09 12:17:34 +0000
committerJoost Peters2005-02-09 12:17:34 +0000
commita13e8a98ff506c100b014ccf7e4b077012c94b50 (patch)
treeb593fa4b474ae8ab19db1f1734916d291544eba9 /backends/PalmOS/Src
parent0da123d601a4803f90032ee429914622e4dcefe0 (diff)
downloadscummvm-rg350-a13e8a98ff506c100b014ccf7e4b077012c94b50.tar.gz
scummvm-rg350-a13e8a98ff506c100b014ccf7e4b077012c94b50.tar.bz2
scummvm-rg350-a13e8a98ff506c100b014ccf7e4b077012c94b50.zip
spelling
svn-id: r16762
Diffstat (limited to 'backends/PalmOS/Src')
-rw-r--r--backends/PalmOS/Src/app.cpp6
-rw-r--r--backends/PalmOS/Src/palmgfx.cpp6
-rw-r--r--backends/PalmOS/Src/shared.h4
3 files changed, 8 insertions, 8 deletions
diff --git a/backends/PalmOS/Src/app.cpp b/backends/PalmOS/Src/app.cpp
index 6f76946246..de6d91ac32 100644
--- a/backends/PalmOS/Src/app.cpp
+++ b/backends/PalmOS/Src/app.cpp
@@ -137,7 +137,7 @@ static void AppStopMathLib() {
}
// Set the screen pitch for direct screen access
-// avaliable only before a game start
+// available only before a game start
void WinScreenGetPitch() {
if (OPTIONS_TST(kOptModeHiDensity)) {
WinScreenGetAttribute(winScreenRowBytes, &(gVars->screenPitch));
@@ -381,8 +381,8 @@ Err AppStart(void) {
GamImportDatabase();
AppStartCheckScreenSize();
- AppStartCheckNotify(); // not fatal error if not avalaible
- AppStartSetMemory(); // set memory required by the differents engines
+ AppStartCheckNotify(); // not fatal error if not available
+ AppStartSetMemory(); // set memory required by the different engines
// force ARM option if bDirectMode
if (!error)
diff --git a/backends/PalmOS/Src/shared.h b/backends/PalmOS/Src/shared.h
index bc1481c50e..4155669825 100644
--- a/backends/PalmOS/Src/shared.h
+++ b/backends/PalmOS/Src/shared.h
@@ -3,11 +3,11 @@
// OSystem : wide display
// consider ony 480x320 screens
-// only avalaible for 320x200 games, so use values instead of vars
+// only available for 320x200 games, so use values instead of vars
#define WIDE_PITCH 320 // pitch in portrait mode
#define WIDE_FULL_WIDTH 320 // original screen size
#define WIDE_HALF_WIDTH 160 // 320 / 2
#define WIDE_HALF_HEIGHT 100 // 200 / 2
-#endif \ No newline at end of file
+#endif
diff --git a/backends/PalmOS/Src/palmgfx.cpp b/backends/PalmOS/Src/palmgfx.cpp
index cee46da4ac..4abf13e061 100644
--- a/backends/PalmOS/Src/palmgfx.cpp
+++ b/backends/PalmOS/Src/palmgfx.cpp
@@ -193,13 +193,13 @@ void OSystem_PALMOS::load_gfx_mode() {
// only for 320x200 games
if (!(_screenWidth == 320 && _screenHeight == 200)) {
- warning("Wide display not avalaible for this game, switching to GFX_NORMAL mode.");
+ warning("Wide display not available for this game, switching to GFX_NORMAL mode.");
_mode = GFX_NORMAL;
}
}
} else {
- warning("HiRes+ not avalaible on this device, switching to GFX_NORMAL mode.");
+ warning("HiRes+ not available on this device, switching to GFX_NORMAL mode.");
_mode = GFX_NORMAL;
}
}
@@ -318,7 +318,7 @@ void OSystem_PALMOS::load_gfx_mode() {
// try to allocate on storage heap, TODO : error if failed
FtrPtrNew(appFileCreator, ftrBufferOverlay, _screenWidth * _screenHeight, (void **)&_tmpScreenP);
FtrPtrNew(appFileCreator, ftrBufferBackup, _screenWidth * _screenHeight, (void **)&_tmpBackupP);
// only if wide mode avalaible
if OPTIONS_TST(kOptModeWide)
FtrPtrNew(appFileCreator, ftrBufferHotSwap, _screenWidth * _screenHeight, (void **)&_tmpHotSwapP);
@@ -318,7 +318,7 @@ void OSystem_PALMOS::load_gfx_mode() {
FtrPtrNew(appFileCreator, ftrBufferOverlay, _screenWidth * _screenHeight, (void **)&_tmpScreenP);
FtrPtrNew(appFileCreator, ftrBufferBackup, _screenWidth * _screenHeight, (void **)&_tmpBackupP);
- // only if wide mode avalaible
+ // only if wide mode available
if OPTIONS_TST(kOptModeWide)
FtrPtrNew(appFileCreator, ftrBufferHotSwap, _screenWidth * _screenHeight, (void **)&_tmpHotSwapP);